@@ -73,7 +73,7 @@ class AddCasterLayoutRequest(RpcRequest):
 				self.add_query_param('VideoLayer.' + str(depth1 + 1) + '.PositionRefer', VideoLayer[depth1].get('PositionRefer'))
 			if VideoLayer[depth1].get('PositionNormalized') is not None:
 				for depth2 in range(len(VideoLayer[depth1].get('PositionNormalized'))):
-					self.add_query_param('VideoLayer.' + str(depth1 + 1) + '.PositionNormalized' + str(depth2 + 1), VideoLayer[depth1].get('PositionNormalized')[depth2])
+					self.add_query_param('VideoLayer.' + str(depth1 + 1) + '.PositionNormalized.' + str(depth2 + 1), VideoLayer[depth1].get('PositionNormalized')[depth2])
 			if VideoLayer[depth1].get('WidthNormalized') is not None:
 				self.add_query_param('VideoLayer.' + str(depth1 + 1) + '.WidthNormalized', VideoLayer[depth1].get('WidthNormalized'))
 	def get_MixLists(self): # RepeatList
