@@ -36,6 +36,11 @@ class AddLiveAppRecordConfigRequest(RpcRequest):
 
 	def set_OssEndpoint(self, OssEndpoint):  # String
 		self.add_query_param('OssEndpoint', OssEndpoint)
+	def get_DelayTime(self): # Integer
+		return self.get_query_params().get('DelayTime')
+
+	def set_DelayTime(self, DelayTime):  # Integer
+		self.add_query_param('DelayTime', DelayTime)
 	def get_TranscodeTemplatess(self): # RepeatList
 		return self.get_query_params().get('TranscodeTemplates')
 
