@@ -25,62 +25,54 @@ class AddLiveDomainRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'live', '2016-11-01', 'AddLiveDomain','live')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_SecurityToken(self):
+	def get_SecurityToken(self): # String
 		return self.get_query_params().get('SecurityToken')
 
-	def set_SecurityToken(self,SecurityToken):
-		self.add_query_param('SecurityToken',SecurityToken)
-
-	def get_Scope(self):
+	def set_SecurityToken(self, SecurityToken):  # String
+		self.add_query_param('SecurityToken', SecurityToken)
+	def get_Scope(self): # String
 		return self.get_query_params().get('Scope')
 
-	def set_Scope(self,Scope):
-		self.add_query_param('Scope',Scope)
-
-	def get_TopLevelDomain(self):
+	def set_Scope(self, Scope):  # String
+		self.add_query_param('Scope', Scope)
+	def get_TopLevelDomain(self): # String
 		return self.get_query_params().get('TopLevelDomain')
 
-	def set_TopLevelDomain(self,TopLevelDomain):
-		self.add_query_param('TopLevelDomain',TopLevelDomain)
-
-	def get_OwnerAccount(self):
+	def set_TopLevelDomain(self, TopLevelDomain):  # String
+		self.add_query_param('TopLevelDomain', TopLevelDomain)
+	def get_OwnerAccount(self): # String
 		return self.get_query_params().get('OwnerAccount')
 
-	def set_OwnerAccount(self,OwnerAccount):
-		self.add_query_param('OwnerAccount',OwnerAccount)
-
-	def get_DomainName(self):
+	def set_OwnerAccount(self, OwnerAccount):  # String
+		self.add_query_param('OwnerAccount', OwnerAccount)
+	def get_DomainName(self): # String
 		return self.get_query_params().get('DomainName')
 
-	def set_DomainName(self,DomainName):
-		self.add_query_param('DomainName',DomainName)
-
-	def get_OwnerId(self):
+	def set_DomainName(self, DomainName):  # String
+		self.add_query_param('DomainName', DomainName)
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_Region(self):
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
+	def get_Region(self): # String
 		return self.get_query_params().get('Region')
 
-	def set_Region(self,Region):
-		self.add_query_param('Region',Region)
-
-	def get_CheckUrl(self):
+	def set_Region(self, Region):  # String
+		self.add_query_param('Region', Region)
+	def get_CheckUrl(self): # String
 		return self.get_query_params().get('CheckUrl')
 
-	def set_CheckUrl(self,CheckUrl):
-		self.add_query_param('CheckUrl',CheckUrl)
-
-	def get_LiveDomainType(self):
+	def set_CheckUrl(self, CheckUrl):  # String
+		self.add_query_param('CheckUrl', CheckUrl)
+	def get_LiveDomainType(self): # String
 		return self.get_query_params().get('LiveDomainType')
 
-	def set_LiveDomainType(self,LiveDomainType):
-		self.add_query_param('LiveDomainType',LiveDomainType)
\ No newline at end of file
+	def set_LiveDomainType(self, LiveDomainType):  # String
+		self.add_query_param('LiveDomainType', LiveDomainType)
