@@ -51,6 +51,11 @@ class AddLiveRecordVodConfigRequest(RpcRequest):
 
 	def set_AppName(self, AppName):  # String
 		self.add_query_param('AppName', AppName)
+	def get_OnDemand(self): # Integer
+		return self.get_query_params().get('OnDemand')
+
+	def set_OnDemand(self, OnDemand):  # Integer
+		self.add_query_param('OnDemand', OnDemand)
 	def get_StreamName(self): # String
 		return self.get_query_params().get('StreamName')
 
