@@ -31,6 +31,11 @@ class DescribeLiveStreamsOnlineListRequest(RpcRequest):
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
+	def get_OnlyStream(self): # String
+		return self.get_query_params().get('OnlyStream')
+
+	def set_OnlyStream(self, OnlyStream):  # String
+		self.add_query_param('OnlyStream', OnlyStream)
 	def get_PageNum(self): # Integer
 		return self.get_query_params().get('PageNum')
 
