@@ -36,16 +36,6 @@ class DescribeLiveUserBillPredictionRequest(RpcRequest):
 
 	def set_StartTime(self, StartTime):  # String
 		self.add_query_param('StartTime', StartTime)
-	def get_Dimension(self): # String
-		return self.get_query_params().get('Dimension')
-
-	def set_Dimension(self, Dimension):  # String
-		self.add_query_param('Dimension', Dimension)
-	def get_Area(self): # String
-		return self.get_query_params().get('Area')
-
-	def set_Area(self, Area):  # String
-		self.add_query_param('Area', Area)
 	def get_EndTime(self): # String
 		return self.get_query_params().get('EndTime')
 
