@@ -50,7 +50,7 @@ class ModifyCasterProgramRequest(RpcRequest):
 				self.add_query_param('Episode.' + str(depth1 + 1) + '.ResourceId', Episode[depth1].get('ResourceId'))
 			if Episode[depth1].get('ComponentId') is not None:
 				for depth2 in range(len(Episode[depth1].get('ComponentId'))):
-					self.add_query_param('Episode.' + str(depth1 + 1) + '.ComponentId' + str(depth2 + 1), Episode[depth1].get('ComponentId')[depth2])
+					self.add_query_param('Episode.' + str(depth1 + 1) + '.ComponentId.' + str(depth2 + 1), Episode[depth1].get('ComponentId')[depth2])
 			if Episode[depth1].get('SwitchType') is not None:
 				self.add_query_param('Episode.' + str(depth1 + 1) + '.SwitchType', Episode[depth1].get('SwitchType'))
 	def get_CasterId(self): # String
