@@ -31,11 +31,11 @@ class ModifyCasterVideoResourceRequest(RpcRequest):
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-	def get_InputType(self): # Integer
-		return self.get_query_params().get('InputType')
+	def get_ImageId(self): # String
+		return self.get_query_params().get('ImageId')
 
-	def set_InputType(self, InputType):  # Integer
-		self.add_query_param('InputType', InputType)
+	def set_ImageId(self, ImageId):  # String
+		self.add_query_param('ImageId', ImageId)
 	def get_EndOffset(self): # Integer
 		return self.get_query_params().get('EndOffset')
 
@@ -76,6 +76,11 @@ class ModifyCasterVideoResourceRequest(RpcRequest):
 
 	def set_LiveStreamUrl(self, LiveStreamUrl):  # String
 		self.add_query_param('LiveStreamUrl', LiveStreamUrl)
+	def get_ImageUrl(self): # String
+		return self.get_query_params().get('ImageUrl')
+
+	def set_ImageUrl(self, ImageUrl):  # String
+		self.add_query_param('ImageUrl', ImageUrl)
 	def get_PtsCallbackInterval(self): # Integer
 		return self.get_query_params().get('PtsCallbackInterval')
 
