@@ -52,6 +52,8 @@ class UpdateCasterSceneAudioRequest(RpcRequest):
 				self.add_query_param('AudioLayer.' + str(depth1 + 1) + '.FixedDelayDuration', AudioLayer[depth1].get('FixedDelayDuration'))
 			if AudioLayer[depth1].get('ValidChannel') is not None:
 				self.add_query_param('AudioLayer.' + str(depth1 + 1) + '.ValidChannel', AudioLayer[depth1].get('ValidChannel'))
+			if AudioLayer[depth1].get('Filter') is not None:
+				self.add_query_param('AudioLayer.' + str(depth1 + 1) + '.Filter', AudioLayer[depth1].get('Filter'))
 	def get_SceneId(self): # String
 		return self.get_query_params().get('SceneId')
 
