@@ -25,40 +25,35 @@ class UpdateCasterSceneConfigRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'live', '2016-11-01', 'UpdateCasterSceneConfig','live')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_LayoutId(self):
+	def get_LayoutId(self): # String
 		return self.get_query_params().get('LayoutId')
 
-	def set_LayoutId(self,LayoutId):
-		self.add_query_param('LayoutId',LayoutId)
-
-	def get_ComponentIds(self):
+	def set_LayoutId(self, LayoutId):  # String
+		self.add_query_param('LayoutId', LayoutId)
+	def get_ComponentIds(self): # RepeatList
 		return self.get_query_params().get('ComponentId')
 
-	def set_ComponentIds(self, ComponentIds):
-		for depth1 in range(len(ComponentIds)):
-			if ComponentIds[depth1] is not None:
-				self.add_query_param('ComponentId.' + str(depth1 + 1) , ComponentIds[depth1])
-
-	def get_CasterId(self):
+	def set_ComponentIds(self, ComponentId):  # RepeatList
+		for depth1 in range(len(ComponentId)):
+			self.add_query_param('ComponentId.' + str(depth1 + 1), ComponentId[depth1])
+	def get_CasterId(self): # String
 		return self.get_query_params().get('CasterId')
 
-	def set_CasterId(self,CasterId):
-		self.add_query_param('CasterId',CasterId)
-
-	def get_OwnerId(self):
+	def set_CasterId(self, CasterId):  # String
+		self.add_query_param('CasterId', CasterId)
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_SceneId(self):
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
+	def get_SceneId(self): # String
 		return self.get_query_params().get('SceneId')
 
-	def set_SceneId(self,SceneId):
-		self.add_query_param('SceneId',SceneId)
\ No newline at end of file
+	def set_SceneId(self, SceneId):  # String
+		self.add_query_param('SceneId', SceneId)
